@@ -1,5 +1,5 @@
 import unittest
-from src.HiddenRequest.HiddenRequest import HiddenRequest
+from HiddenRequest.HiddenRequest import HiddenRequest
 
 class TestHiddenRequest(unittest.TestCase):
     
